@@ -7,7 +7,7 @@
 #  define LIBKEXIV2_NO_EXPORT
 #else
 #  ifndef LIBKEXIV2_EXPORT
-#    ifdef KF5KExiv2_EXPORTS
+#    ifdef KExiv2_EXPORTS
         /* We are building this library */
 #      define LIBKEXIV2_EXPORT __attribute__((visibility("default")))
 #    else
@@ -39,4 +39,4 @@
 #  endif
 #endif
 
-#endif
+#endif /* LIBKEXIV2_EXPORT_H */
